# `testpypiazapala` - My Simple Project

* Opt1
* Opt2
* Opt3

## Install

```python
pip install testpypiazapala
```

### Usage

```python
from testpypiazapala.m_mod_azapala import name as n
from testpypiazapala.m_mod_azapala import get_numpy_arr
>>> n("Name", "surname")
Name Surname
>>> get_numpy_arr([1, 2, 3, 4, 5])
[1 2 3 4 5]
```